==> vtk6-6.3.0-8-armv7h.pkg.tar.xz: vtk/vtkXMLTreeReader.java <==
// java wrapper for vtkXMLTreeReader object
//

package vtk;
import vtk.*;

public class vtkXMLTreeReader extends vtkTreeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetFileName_2();
  public String GetFileName()
    { return GetFileName_2(); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native String GetXMLString_4();
  public String GetXMLString()
    { return GetXMLString_4(); }

  private native void SetXMLString_5(String id0);
  public void SetXMLString(String id0)
    { SetXMLString_5(id0); }

  private native String GetEdgePedigreeIdArrayName_6();
  public String GetEdgePedigreeIdArrayName()
    { return GetEdgePedigreeIdArrayName_6(); }

  private native void SetEdgePedigreeIdArrayName_7(String id0);
  public void SetEdgePedigreeIdArrayName(String id0)
    { SetEdgePedigreeIdArrayName_7(id0); }

  private native String GetVertexPedigreeIdArrayName_8();
  public String GetVertexPedigreeIdArrayName()
    { return GetVertexPedigreeIdArrayName_8(); }

  private native void SetVertexPedigreeIdArrayName_9(String id0);
  public void SetVertexPedigreeIdArrayName(String id0)
    { SetVertexPedigreeIdArrayName_9(id0); }

  private native void SetGenerateEdgePedigreeIds_10(boolean id0);
  public void SetGenerateEdgePedigreeIds(boolean id0)
    { SetGenerateEdgePedigreeIds_10(id0); }

  private native boolean GetGenerateEdgePedigreeIds_11();
  public boolean GetGenerateEdgePedigreeIds()
    { return GetGenerateEdgePedigreeIds_11(); }

  private native void GenerateEdgePedigreeIdsOn_12();
  public void GenerateEdgePedigreeIdsOn()
    { GenerateEdgePedigreeIdsOn_12(); }

  private native void GenerateEdgePedigreeIdsOff_13();
  public void GenerateEdgePedigreeIdsOff()
    { GenerateEdgePedigreeIdsOff_13(); }

  private native void SetGenerateVertexPedigreeIds_14(boolean id0);
  public void SetGenerateVertexPedigreeIds(boolean id0)
    { SetGenerateVertexPedigreeIds_14(id0); }

  private native boolean GetGenerateVertexPedigreeIds_15();
  public boolean GetGenerateVertexPedigreeIds()
    { return GetGenerateVertexPedigreeIds_15(); }

  private native void GenerateVertexPedigreeIdsOn_16();
  public void GenerateVertexPedigreeIdsOn()
    { GenerateVertexPedigreeIdsOn_16(); }

  private native void GenerateVertexPedigreeIdsOff_17();
  public void GenerateVertexPedigreeIdsOff()
    { GenerateVertexPedigreeIdsOff_17(); }

  private native boolean GetMaskArrays_18();
  public boolean GetMaskArrays()
    { return GetMaskArrays_18(); }

  private native void SetMaskArrays_19(boolean id0);
  public void SetMaskArrays(boolean id0)
    { SetMaskArrays_19(id0); }

  private native void MaskArraysOn_20();
  public void MaskArraysOn()
    { MaskArraysOn_20(); }

  private native void MaskArraysOff_21();
  public void MaskArraysOff()
    { MaskArraysOff_21(); }

  private native boolean GetReadCharData_22();
  public boolean GetReadCharData()
    { return GetReadCharData_22(); }

  private native void SetReadCharData_23(boolean id0);
  public void SetReadCharData(boolean id0)
    { SetReadCharData_23(id0); }

  private native void ReadCharDataOn_24();
  public void ReadCharDataOn()
    { ReadCharDataOn_24(); }

  private native void ReadCharDataOff_25();
  public void ReadCharDataOff()
    { ReadCharDataOff_25(); }

  private native boolean GetReadTagName_26();
  public boolean GetReadTagName()
    { return GetReadTagName_26(); }

  private native void SetReadTagName_27(boolean id0);
  public void SetReadTagName(boolean id0)
    { SetReadTagName_27(id0); }

  private native void ReadTagNameOn_28();
  public void ReadTagNameOn()
    { ReadTagNameOn_28(); }

  private native void ReadTagNameOff_29();
  public void ReadTagNameOff()
    { ReadTagNameOff_29(); }

  public vtkXMLTreeReader() { super(); }

  public vtkXMLTreeReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv7h.pkg.tar.xz: vtk/vtkXMLTreeReader.java <==
// java wrapper for vtkXMLTreeReader object
//

package vtk;
import vtk.*;

public class vtkXMLTreeReader extends vtkTreeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetFileName_2();
  public String GetFileName()
    { return GetFileName_2(); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native String GetXMLString_4();
  public String GetXMLString()
    { return GetXMLString_4(); }

  private native void SetXMLString_5(String id0);
  public void SetXMLString(String id0)
    { SetXMLString_5(id0); }

  private native String GetEdgePedigreeIdArrayName_6();
  public String GetEdgePedigreeIdArrayName()
    { return GetEdgePedigreeIdArrayName_6(); }

  private native void SetEdgePedigreeIdArrayName_7(String id0);
  public void SetEdgePedigreeIdArrayName(String id0)
    { SetEdgePedigreeIdArrayName_7(id0); }

  private native String GetVertexPedigreeIdArrayName_8();
  public String GetVertexPedigreeIdArrayName()
    { return GetVertexPedigreeIdArrayName_8(); }

  private native void SetVertexPedigreeIdArrayName_9(String id0);
  public void SetVertexPedigreeIdArrayName(String id0)
    { SetVertexPedigreeIdArrayName_9(id0); }

  private native void SetGenerateEdgePedigreeIds_10(boolean id0);
  public void SetGenerateEdgePedigreeIds(boolean id0)
    { SetGenerateEdgePedigreeIds_10(id0); }

  private native boolean GetGenerateEdgePedigreeIds_11();
  public boolean GetGenerateEdgePedigreeIds()
    { return GetGenerateEdgePedigreeIds_11(); }

  private native void GenerateEdgePedigreeIdsOn_12();
  public void GenerateEdgePedigreeIdsOn()
    { GenerateEdgePedigreeIdsOn_12(); }

  private native void GenerateEdgePedigreeIdsOff_13();
  public void GenerateEdgePedigreeIdsOff()
    { GenerateEdgePedigreeIdsOff_13(); }

  private native void SetGenerateVertexPedigreeIds_14(boolean id0);
  public void SetGenerateVertexPedigreeIds(boolean id0)
    { SetGenerateVertexPedigreeIds_14(id0); }

  private native boolean GetGenerateVertexPedigreeIds_15();
  public boolean GetGenerateVertexPedigreeIds()
    { return GetGenerateVertexPedigreeIds_15(); }

  private native void GenerateVertexPedigreeIdsOn_16();
  public void GenerateVertexPedigreeIdsOn()
    { GenerateVertexPedigreeIdsOn_16(); }

  private native void GenerateVertexPedigreeIdsOff_17();
  public void GenerateVertexPedigreeIdsOff()
    { GenerateVertexPedigreeIdsOff_17(); }

  private native boolean GetMaskArrays_18();
  public boolean GetMaskArrays()
    { return GetMaskArrays_18(); }

  private native void SetMaskArrays_19(boolean id0);
  public void SetMaskArrays(boolean id0)
    { SetMaskArrays_19(id0); }

  private native void MaskArraysOn_20();
  public void MaskArraysOn()
    { MaskArraysOn_20(); }

  private native void MaskArraysOff_21();
  public void MaskArraysOff()
    { MaskArraysOff_21(); }

  private native boolean GetReadCharData_22();
  public boolean GetReadCharData()
    { return GetReadCharData_22(); }

  private native void SetReadCharData_23(boolean id0);
  public void SetReadCharData(boolean id0)
    { SetReadCharData_23(id0); }

  private native void ReadCharDataOn_24();
  public void ReadCharDataOn()
    { ReadCharDataOn_24(); }

  private native void ReadCharDataOff_25();
  public void ReadCharDataOff()
    { ReadCharDataOff_25(); }

  private native boolean GetReadTagName_26();
  public boolean GetReadTagName()
    { return GetReadTagName_26(); }

  private native void SetReadTagName_27(boolean id0);
  public void SetReadTagName(boolean id0)
    { SetReadTagName_27(id0); }

  private native void ReadTagNameOn_28();
  public void ReadTagNameOn()
    { ReadTagNameOn_28(); }

  private native void ReadTagNameOff_29();
  public void ReadTagNameOff()
    { ReadTagNameOff_29(); }

  public vtkXMLTreeReader() { super(); }

  public vtkXMLTreeReader(long id) { super(id); }
  public native long   VTKInit();

}
